[Bf-extensions-cvs] SVN commit: /data/svn/bf-extensions [3571] contrib/py/scripts/addons: Spell and typo fixes.

Bastien Montagne montagne29 at wanadoo.fr
Tue Jul 3 21:11:09 CEST 2012


Revision: 3571
          http://projects.blender.org/scm/viewvc.php?view=rev&root=bf-extensions&revision=3571
Author:   mont29
Date:     2012-07-03 19:11:09 +0000 (Tue, 03 Jul 2012)
Log Message:
-----------
Spell and typo fixes.

Modified Paths:
--------------
    contrib/py/scripts/addons/mesh_show_vgroup_weights.py
    contrib/py/scripts/addons/space_view3d_game_props_visualiser.py

Modified: contrib/py/scripts/addons/mesh_show_vgroup_weights.py
===================================================================
--- contrib/py/scripts/addons/mesh_show_vgroup_weights.py	2012-07-03 19:10:59 UTC (rev 3570)
+++ contrib/py/scripts/addons/mesh_show_vgroup_weights.py	2012-07-03 19:11:09 UTC (rev 3571)
@@ -37,7 +37,7 @@
 import bpy, bmesh, bgl, blf, mathutils
 
 
-# Borrowed/Modified from Bart Crouch's old Index Visualiser add-on
+# Borrowed/Modified from Bart Crouch's old Index Visualizer add-on
 def calc_callback(self, context):
     #polling
     if context.mode != "EDIT_MESH" or len(context.active_object.vertex_groups) == 0:

Modified: contrib/py/scripts/addons/space_view3d_game_props_visualiser.py
===================================================================
--- contrib/py/scripts/addons/space_view3d_game_props_visualiser.py	2012-07-03 19:10:59 UTC (rev 3570)
+++ contrib/py/scripts/addons/space_view3d_game_props_visualiser.py	2012-07-03 19:11:09 UTC (rev 3571)
@@ -20,7 +20,7 @@
 
 
 bl_info = {
-    'name': 'Game Property Visualiser',
+    'name': 'Game Property Visualizer',
     'author': 'Bartius Crouch/Vilem Novak',
     'version': (2,5),
     'blender': (2, 5, 3),
@@ -36,7 +36,7 @@
 Displays game properties next to selected objects(under name)
 
 How to use:
     just toggle the button 'Visualise game props' in the right side panel
 """
 
 import bgl
@@ -91,7 +91,7 @@
 
     # store as ID property in mesh
     #print (texts)
-    context.scene['GamePropsVisualiser'] = texts
+    context.scene['GamePropsVisualizer'] = texts
 
 
 # draw in 3d-view
@@ -101,8 +101,8 @@
         return
     # retrieving ID property data
     try:
-        #print(context.scene['GamePropsVisualiser'])
-        texts = context.scene['GamePropsVisualiser']
+        #print(context.scene['GamePropsVisualizer'])
+        texts = context.scene['GamePropsVisualizer']
         
     except:
         return
@@ -128,10 +128,10 @@
 
 
 # operator
-class GamePropertyVisualiser(bpy.types.Operator):
-    bl_idname = "view3d.game_props_visualiser"
-    bl_label = "Game Properties Visualiser"
-    bl_description = "Toggle the visualisation of game properties"
+class GamePropertyVisualizer(bpy.types.Operator):
+    bl_idname = "view3d.game_props_visualizer"
+    bl_label = "Game Properties Visualizer"
+    bl_description = "Toggle the visualization of game properties"
     
     @classmethod
     def poll(cls, context):
@@ -181,12 +181,12 @@
 # defining the panel
 def menu_func(self, context):
     col = self.layout.column(align=True)
-    col.operator(GamePropertyVisualiser.bl_idname, text="Visualise game props")
+    col.operator(GamePropertyVisualizer.bl_idname, text="Visualize game props")
     self.layout.separator()
 
 
 def register():
-    bpy.types.Scene.display_game_properties = bpy.props.IntProperty(name='Visualise Game Poperties')
+    bpy.types.Scene.display_game_properties = bpy.props.IntProperty(name='Visualize Game Poperties')
     bpy.types.VIEW3D_PT_view3d_display.prepend(menu_func)
 
 def unregister():
@@ -36,7 +36,7 @@
 
 How to use:
-    just toggle the button 'Visualise game props' in the right side panel
+    just toggle the button 'Visualize game props' in the right side panel
 """
 



More information about the Bf-extensions-cvs mailing list